# PyFLOTRAN
Set of pre- and post-processing scripts for PFLOTRAN

## Installation
Configure the conda environment running

`conda env create -f /config/conda_env.yml`

## Instructions

One can easily
